package io.swagger.api;

import java.util.Date;
import io.swagger.model.EcmwfForecastOnpointDayObj;
import io.swagger.model.EcmwfForecastOnpointHourObj;
import io.swagger.model.ErrorObj;
import org.joda.time.LocalDate;

import java.io.InputStream;
import java.io.OutputStream;
import java.util.List;
import java.util.Map;
import javax.ws.rs.*;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.MediaType;
import org.apache.cxf.jaxrs.ext.multipart.*;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.responses.ApiResponses;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.media.ArraySchema;
import io.swagger.v3.oas.annotations.media.Content;
import io.swagger.v3.oas.annotations.media.Schema;

/**
 * ECMWF Forecast - A Weather Source API
 *
 * <p>Daily and hourly forecast data from the ECMWF model for latitude/longitude points, ZIP/Postal Codes, and Designated Market Areas. Hourly forecast is up to 10 days out from current day. Daily forecast is up to 15 days out from current day. The Weather Source ECMWF Forecast API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate analysis. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.    **IMPORTANT:** To authenticate to the Weather Source ECMWF Forecast API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.      When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
 *
 */
@Path("/")
public interface OnpointsApi  {

    /**
     * A day of ECMWF forecast data for an OnPoint™ point.
     *
     * Returns a single day of ECMWF forecast data for an OnPoint™ point. The provided date must exist within the current valid 15-day forecast range.  **IMPORTANT:** To authenticate to the Weather Source ECMWF Forecast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     *
     */
    @GET
    @Path("/onpoints/{onpointId}/days/{date}")
    @Produces({ "application/json" })
    @Operation(summary = "A day of ECMWF forecast data for an OnPoint™ point.", tags={  })
    @ApiResponses(value = { 
        @ApiResponse(responseCode = "200", description = "Daily ECMWF forecast response for an OnPoint™ point.", content = @Content(schema = @Schema(implementation = EcmwfForecastOnpointDayObj.class))),
        @ApiResponse(responseCode = "200", description = "Unexpected error response", content = @Content(schema = @Schema(implementation = ErrorObj.class))) })
    public EcmwfForecastOnpointDayObj onpointsOnpointIdDaysDateGet(@PathParam("onpointId") Integer onpointId, @PathParam("date") LocalDate date, @QueryParam("fields")List<String> fields, @QueryParam("unitScale")@DefaultValue("IMPERIAL") String unitScale);

    /**
     * A contiguous range of daily ECMWF forecast data for an OnPoint™ point.
     *
     * Returns a contiguous range of daily ECMWF forecast data for an OnPoint™ point. The provided dates must exist within the current valid 15-day forecast range.  **IMPORTANT:** To authenticate to the Weather Source ECMWF Forecast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     *
     */
    @GET
    @Path("/onpoints/{onpointId}/days/{dateStart},{dateEnd}")
    @Produces({ "application/json" })
    @Operation(summary = "A contiguous range of daily ECMWF forecast data for an OnPoint™ point.", tags={  })
    @ApiResponses(value = { 
        @ApiResponse(responseCode = "200", description = "Daily ECMWF forecast response for an OnPoint™ point.", content = @Content(schema = @Schema(implementation = EcmwfForecastOnpointDayObj.class))),
        @ApiResponse(responseCode = "200", description = "Unexpected error response", content = @Content(schema = @Schema(implementation = ErrorObj.class))) })
    public EcmwfForecastOnpointDayObj onpointsOnpointIdDaysDateStartdateEndGet(@PathParam("onpointId") Integer onpointId, @PathParam("dateStart") LocalDate dateStart, @PathParam("dateEnd") LocalDate dateEnd, @QueryParam("fields")List<String> fields, @QueryParam("unitScale")@DefaultValue("IMPERIAL") String unitScale);

    /**
     * The complete daily ECMWF forecast for an OnPoint™ point.
     *
     * Returns the complete set of ECMWF forecast data for an OnPoint™ point.  *Alternatively using a query that specificies just the days required for your purposes will improve the query response time.*  **IMPORTANT:** To authenticate to the Weather Source ECMWF Forecast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     *
     */
    @GET
    @Path("/onpoints/{onpointId}/days")
    @Produces({ "application/json" })
    @Operation(summary = "The complete daily ECMWF forecast for an OnPoint™ point.", tags={  })
    @ApiResponses(value = { 
        @ApiResponse(responseCode = "200", description = "Daily ECMWF forecast response for an OnPoint™ point.", content = @Content(schema = @Schema(implementation = EcmwfForecastOnpointDayObj.class))),
        @ApiResponse(responseCode = "200", description = "Unexpected error response", content = @Content(schema = @Schema(implementation = ErrorObj.class))) })
    public EcmwfForecastOnpointDayObj onpointsOnpointIdDaysGet(@PathParam("onpointId") Integer onpointId, @QueryParam("fields")List<String> fields, @QueryParam("unitScale")@DefaultValue("IMPERIAL") String unitScale);

    /**
     * The complete hourly ECMWF forecast for an OnPoint™ point.
     *
     * Returns the complete set of ECMWF forecast data for an OnPoint™ point.  *Alternatively using a query that specificies just the hours required for your purposes will improve the query response time.*  **IMPORTANT:** To authenticate to the Weather Source ECMWF Forecast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     *
     */
    @GET
    @Path("/onpoints/{onpointId}/hours")
    @Produces({ "application/json" })
    @Operation(summary = "The complete hourly ECMWF forecast for an OnPoint™ point.", tags={  })
    @ApiResponses(value = { 
        @ApiResponse(responseCode = "200", description = "Hourly ECMWF forecast response for an OnPoint™ point.", content = @Content(schema = @Schema(implementation = EcmwfForecastOnpointHourObj.class))),
        @ApiResponse(responseCode = "200", description = "Unexpected error response", content = @Content(schema = @Schema(implementation = ErrorObj.class))) })
    public EcmwfForecastOnpointHourObj onpointsOnpointIdHoursGet(@PathParam("onpointId") Integer onpointId, @QueryParam("fields")List<String> fields, @QueryParam("unitScale")@DefaultValue("IMPERIAL") String unitScale);

    /**
     * An hour of ECMWF forecast data for an OnPoint™ point.
     *
     * Returns a single hour of ECMWF forecast data for an OnPoint™ point. The provided timestamp must exist within the current valid 10-day forecast range.  **IMPORTANT:** To authenticate to the Weather Source ECMWF Forecast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     *
     */
    @GET
    @Path("/onpoints/{onpointId}/hours/{timestamp}")
    @Produces({ "application/json" })
    @Operation(summary = "An hour of ECMWF forecast data for an OnPoint™ point.", tags={  })
    @ApiResponses(value = { 
        @ApiResponse(responseCode = "200", description = "Hourly ECMWF forecast response for an OnPoint™ point.", content = @Content(schema = @Schema(implementation = EcmwfForecastOnpointHourObj.class))),
        @ApiResponse(responseCode = "200", description = "Unexpected error response", content = @Content(schema = @Schema(implementation = ErrorObj.class))) })
    public EcmwfForecastOnpointHourObj onpointsOnpointIdHoursTimestampGet(@PathParam("onpointId") Integer onpointId, @PathParam("timestamp") Date timestamp, @QueryParam("fields")List<String> fields, @QueryParam("unitScale")@DefaultValue("IMPERIAL") String unitScale);

    /**
     * A contiguous range of hourly ECMWF forecast data for an OnPoint™ point.
     *
     * Returns a contiguous range of hourly ECMWF forecast data for an OnPoint™ point. The provided timestamps must exist within the current valid 10-day forecast range.  **IMPORTANT:** To authenticate to the Weather Source ECMWF Forecast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     *
     */
    @GET
    @Path("/onpoints/{onpointId}/hours/{timestampStart},{timestampEnd}")
    @Produces({ "application/json" })
    @Operation(summary = "A contiguous range of hourly ECMWF forecast data for an OnPoint™ point.", tags={  })
    @ApiResponses(value = { 
        @ApiResponse(responseCode = "200", description = "Hourly ECMWF forecast response for an OnPoint™ point.", content = @Content(schema = @Schema(implementation = EcmwfForecastOnpointHourObj.class))),
        @ApiResponse(responseCode = "200", description = "Unexpected error response", content = @Content(schema = @Schema(implementation = ErrorObj.class))) })
    public EcmwfForecastOnpointHourObj onpointsOnpointIdHoursTimestampStarttimestampEndGet(@PathParam("onpointId") Integer onpointId, @PathParam("timestampStart") Date timestampStart, @PathParam("timestampEnd") Date timestampEnd, @QueryParam("fields")List<String> fields, @QueryParam("unitScale")@DefaultValue("IMPERIAL") String unitScale);
}
