package io.swagger.api;

import java.util.Date;
import io.swagger.model.EcmwfForecastPostcodeDayObj;
import io.swagger.model.EcmwfForecastPostcodeHourObj;
import io.swagger.model.ErrorObj;
import org.joda.time.LocalDate;

import java.io.InputStream;
import java.io.OutputStream;
import java.util.List;
import java.util.Map;
import javax.ws.rs.*;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.MediaType;
import org.apache.cxf.jaxrs.ext.multipart.*;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.responses.ApiResponses;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.media.ArraySchema;
import io.swagger.v3.oas.annotations.media.Content;
import io.swagger.v3.oas.annotations.media.Schema;

/**
 * ECMWF Forecast - A Weather Source API
 *
 * <p>Daily and hourly forecast data from the ECMWF model for latitude/longitude points, ZIP/Postal Codes, and Designated Market Areas. Hourly forecast is up to 10 days out from current day. Daily forecast is up to 15 days out from current day. The Weather Source ECMWF Forecast API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate analysis. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.    **IMPORTANT:** To authenticate to the Weather Source ECMWF Forecast API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.      When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
 *
 */
@Path("/")
public interface PostcodesApi  {

    /**
     * A day of ECMWF forecast data for a postcode.
     *
     * Returns a single day of ECMWF forecast data for a postcode. The provided date must exist within the current valid 15-day forecast range.  **IMPORTANT:** To authenticate to the Weather Source ECMWF Forecast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     *
     */
    @GET
    @Path("/postcodes/{postcode},{countryCode}/days/{date}")
    @Produces({ "application/json" })
    @Operation(summary = "A day of ECMWF forecast data for a postcode.", tags={  })
    @ApiResponses(value = { 
        @ApiResponse(responseCode = "200", description = "Daily ECMWF forecast response for a postcode.", content = @Content(schema = @Schema(implementation = EcmwfForecastPostcodeDayObj.class))),
        @ApiResponse(responseCode = "200", description = "Unexpected error response", content = @Content(schema = @Schema(implementation = ErrorObj.class))) })
    public EcmwfForecastPostcodeDayObj postcodesPostcodecountryCodeDaysDateGet(@PathParam("postcode") String postcode, @PathParam("countryCode") String countryCode, @PathParam("date") LocalDate date, @QueryParam("fields")List<String> fields, @QueryParam("unitScale")@DefaultValue("IMPERIAL") String unitScale);

    /**
     * A contiguous range of daily ECMWF forecast data for a postcode.
     *
     * Returns a contiguous range of daily ECMWF forecast data for a postcode. The provided dates must exist within the current valid 15-day forecast range.  **IMPORTANT:** To authenticate to the Weather Source ECMWF Forecast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     *
     */
    @GET
    @Path("/postcodes/{postcode},{countryCode}/days/{dateStart},{dateEnd}")
    @Produces({ "application/json" })
    @Operation(summary = "A contiguous range of daily ECMWF forecast data for a postcode.", tags={  })
    @ApiResponses(value = { 
        @ApiResponse(responseCode = "200", description = "Daily ECMWF forecast response for a postcode.", content = @Content(schema = @Schema(implementation = EcmwfForecastPostcodeDayObj.class))),
        @ApiResponse(responseCode = "200", description = "Unexpected error response", content = @Content(schema = @Schema(implementation = ErrorObj.class))) })
    public EcmwfForecastPostcodeDayObj postcodesPostcodecountryCodeDaysDateStartdateEndGet(@PathParam("postcode") String postcode, @PathParam("countryCode") String countryCode, @PathParam("dateStart") LocalDate dateStart, @PathParam("dateEnd") LocalDate dateEnd, @QueryParam("fields")List<String> fields, @QueryParam("unitScale")@DefaultValue("IMPERIAL") String unitScale);

    /**
     * The complete daily ECMWF forecast for a postcode.
     *
     * Returns the complete set of ECMWF forecast data for a postcode.  *Alternatively using a query that specificies just the days required for your purposes will improve the query response time.*  **IMPORTANT:** To authenticate to the Weather Source ECMWF Forecast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     *
     */
    @GET
    @Path("/postcodes/{postcode},{countryCode}/days")
    @Produces({ "application/json" })
    @Operation(summary = "The complete daily ECMWF forecast for a postcode.", tags={  })
    @ApiResponses(value = { 
        @ApiResponse(responseCode = "200", description = "Daily ECMWF forecast response for a postcode.", content = @Content(schema = @Schema(implementation = EcmwfForecastPostcodeDayObj.class))),
        @ApiResponse(responseCode = "200", description = "Unexpected error response", content = @Content(schema = @Schema(implementation = ErrorObj.class))) })
    public EcmwfForecastPostcodeDayObj postcodesPostcodecountryCodeDaysGet(@PathParam("postcode") String postcode, @PathParam("countryCode") String countryCode, @QueryParam("fields")List<String> fields, @QueryParam("unitScale")@DefaultValue("IMPERIAL") String unitScale);

    /**
     * The complete hourly ECMWF forecast for a postcode.
     *
     * Returns the complete set of ECMWF forecast data for a postcode.  *Alternatively using a query that specificies just the hours required for your purposes will improve the query response time.*  **IMPORTANT:** To authenticate to the Weather Source ECMWF Forecast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     *
     */
    @GET
    @Path("/postcodes/{postcode},{countryCode}/hours")
    @Produces({ "application/json" })
    @Operation(summary = "The complete hourly ECMWF forecast for a postcode.", tags={  })
    @ApiResponses(value = { 
        @ApiResponse(responseCode = "200", description = "Hourly ECMWF forecast response for a postcode.", content = @Content(schema = @Schema(implementation = EcmwfForecastPostcodeHourObj.class))),
        @ApiResponse(responseCode = "200", description = "Unexpected error response", content = @Content(schema = @Schema(implementation = ErrorObj.class))) })
    public EcmwfForecastPostcodeHourObj postcodesPostcodecountryCodeHoursGet(@PathParam("postcode") String postcode, @PathParam("countryCode") String countryCode, @QueryParam("fields")List<String> fields, @QueryParam("unitScale")@DefaultValue("IMPERIAL") String unitScale);

    /**
     * An hour of ECMWF forecast data for a postcode.
     *
     * Returns a single hour of ECMWF forecast data for a postcode. The provided timestamp must exist within the current valid 10-day forecast range.  **IMPORTANT:** To authenticate to the Weather Source ECMWF Forecast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     *
     */
    @GET
    @Path("/postcodes/{postcode},{countryCode}/hours/{timestamp}")
    @Produces({ "application/json" })
    @Operation(summary = "An hour of ECMWF forecast data for a postcode.", tags={  })
    @ApiResponses(value = { 
        @ApiResponse(responseCode = "200", description = "Hourly ECMWF forecast response for a postcode.", content = @Content(schema = @Schema(implementation = EcmwfForecastPostcodeHourObj.class))),
        @ApiResponse(responseCode = "200", description = "Unexpected error response", content = @Content(schema = @Schema(implementation = ErrorObj.class))) })
    public EcmwfForecastPostcodeHourObj postcodesPostcodecountryCodeHoursTimestampGet(@PathParam("postcode") String postcode, @PathParam("countryCode") String countryCode, @PathParam("timestamp") Date timestamp, @QueryParam("fields")List<String> fields, @QueryParam("unitScale")@DefaultValue("IMPERIAL") String unitScale);

    /**
     * A contiguous range of hourly ECMWF forecast data for a postcode.
     *
     * Returns a contiguous range of hourly ECMWF forecast data for a postcode. The provided timestamps must exist within the current valid 10-day forecast range.  **IMPORTANT:** To authenticate to the Weather Source ECMWF Forecast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     *
     */
    @GET
    @Path("/postcodes/{postcode},{countryCode}/hours/{timestampStart},{timestampEnd}")
    @Produces({ "application/json" })
    @Operation(summary = "A contiguous range of hourly ECMWF forecast data for a postcode.", tags={  })
    @ApiResponses(value = { 
        @ApiResponse(responseCode = "200", description = "Hourly ECMWF forecast response for a postcode.", content = @Content(schema = @Schema(implementation = EcmwfForecastPostcodeHourObj.class))),
        @ApiResponse(responseCode = "200", description = "Unexpected error response", content = @Content(schema = @Schema(implementation = ErrorObj.class))) })
    public EcmwfForecastPostcodeHourObj postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet(@PathParam("postcode") String postcode, @PathParam("countryCode") String countryCode, @PathParam("timestampStart") Date timestampStart, @PathParam("timestampEnd") Date timestampEnd, @QueryParam("fields")List<String> fields, @QueryParam("unitScale")@DefaultValue("IMPERIAL") String unitScale);
}
